@@ -8,6 +8,7 @@ from container_hub.models import (
     KubernetesJobConfig,
     KubernetesContainer,
     NodeAffinityConfig,
+    MountPointType,
 )
 from functools import cached_property
 from kubernetes.client.models import V1DeleteOptions
@@ -26,13 +27,15 @@ from hikaru.model.rel_1_20 import (
     VolumeMount,
     Volume,
     HostPathVolumeSource,
+    ConfigMapVolumeSource,
+    SecretVolumeSource,
     LocalObjectReference,
     Affinity,
     NodeAffinity,
     NodeSelectorTerm,
     NodeSelector,
     NodeSelectorRequirement,
-    EmptyDirVolumeSource
+    EmptyDirVolumeSource,
 )
 
 
@@ -173,7 +176,29 @@ def get_simulation_job(cfg: KubernetesJobConfig) -> Job:
                             ),
                         )
                         for mount in cfg.mount_points
-                    ] + [Volume(name='shared-data', emptyDir=EmptyDirVolumeSource())],
+                        if mount.type == MountPointType.HOSTPATH
+                    ]
+                    + [
+                        Volume(name=mount.name, emptyDir=EmptyDirVolumeSource())
+                        for mount in cfg.mount_points
+                        if mount.type == MountPointType.EMPTYDIR
+                    ]
+                    + [
+                        Volume(
+                            name=mount.name,
+                            configMap=ConfigMapVolumeSource(name=mount.local_path),
+                        )
+                        for mount in cfg.mount_points
+                        if mount.type == MountPointType.CONFIGMAP
+                    ]
+                    + [
+                        Volume(
+                            name=mount.name,
+                            secret=SecretVolumeSource(secretName=mount.local_path),
+                        )
+                        for mount in cfg.mount_points
+                        if mount.type == MountPointType.CONFIGMAP
+                    ],
                     restartPolicy="Never",
                 ),
             ),
@@ -192,7 +217,12 @@ def get_container(cfg: KubernetesContainer) -> Container:
         name=cfg.name,
         image=cfg.image,
         imagePullPolicy="IfNotPresent",
-        resources=ResourceRequirements(limits=cfg.resources.limits.to_dict(), requests=cfg.resources.requests.to_dict()) if cfg.resources is not None else ResourceRequirements(),
+        resources=ResourceRequirements(
+            limits=cfg.resources.limits.to_dict(),
+            requests=cfg.resources.requests.to_dict(),
+        )
+        if cfg.resources is not None
+        else ResourceRequirements(),
         args=cfg.args,
         env=[
             EnvVar(
@@ -202,7 +232,7 @@ def get_container(cfg: KubernetesContainer) -> Container:
             for envvar in cfg.envs
         ],
         volumeMounts=[
-            VolumeMount(mountPath=mount.mount_path, name=mount.name)
+            VolumeMount(mountPath=mount.mount_path, name=mount.name, readOnly=mount.read_only)
             for mount in cfg.mount_points
         ],
         ports=[ContainerPort(containerPort=port) for port in cfg.ports],
