@@ -1,6 +1,7 @@
 import pytest
 from dataclasses import asdict
 from container_hub import get_backend
+from container_hub.models import MountPointType
 from container_hub.carriers.docker.backend import DockerBackend
 from container_hub.carriers.marathon.backend import MarathonBackend
 from container_hub.carriers.kubernetes.backend import KubernetesBackend
@@ -73,11 +74,31 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
                     "local_path": "/local/path/one",
                     "mount_path": "mount_path_1",
                     "read_only": True,
+                    "type": MountPointType.HOSTPATH
                 },
                 {
                     "local_path": "/local/path/two",
                     "mount_path": "mount_path_2",
                     "read_only": False,
+                    "type": MountPointType.HOSTPATH
+                },
+                {
+                    "local_path": "scheduler-config",
+                    "mount_path": "/etc/config/config.yaml",
+                    "read_only": True,
+                    "type": MountPointType.CONFIGMAP
+                },
+                {
+                    "local_path": "scheduler-secret",
+                    "mount_path": "/etc/secrets/",
+                    "read_only": True,
+                    "type": MountPointType.SECRET
+                },
+                {
+                    "local_path": "shared-data",
+                    "mount_path": "/mnt/results/",
+                    "read_only": False,
+                    "type": MountPointType.EMPTYDIR
                 },
             ],
             "resources": {
@@ -100,11 +121,13 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
                     "local_path": "/local/path/one",
                     "mount_path": "mount_path_1",
                     "read_only": True,
+                    "type": MountPointType.HOSTPATH
                 },
                 {
                     "local_path": "/local/path/two",
                     "mount_path": "mount_path_2",
                     "read_only": False,
+                    "type": MountPointType.HOSTPATH
                 },
             ],
             "resources": {
