@@ -28,6 +28,9 @@ CONTAINER_HUB_KUBERNETES_CONTAINER_DEFAULTS = {
         "mounts": {
             "/local/path/one": {"bind": "mount_path_1", "ro": True},
             "/local/path/two": {"bind": "mount_path_2", "ro": False},
+            "scheduler-config": {"bind": "/etc/config/config.yaml", "ro": True, "type": "CONFIGMAP"},
+            "scheduler-secret": {"bind": "/etc/secrets/", "ro": True, "type": "SECRET"},
+            "shared-data": {"bind": "/mnt/results/", "ro": False, "type": "EMPTYDIR"}
         },
         "resources": {
             "limits": {
